@@ -33,6 +33,10 @@
   out <- capture.output(expect_warning(validator(.file="yamltests/invalidR.yaml")))
   expect_true(any(nchar(out)>0))
 
+## Duplicate names ----
+  v <- validator(.file="yamltests/duplicate_name.yaml") 
+  nms <- names(v)
+  expect_equal(nms, unique(nms))
 
 ## Parsing options ----
   v <- validator(.file="yamltests/yamloptions.yaml") 
@@ -163,3 +167,53 @@
   expect_identical(validate:::replace_in(e)
     , expression(x %vin% y | x %vin% z)[[1]])
   
+
+## negating numerical expressions
+e  <- expression(x >  1, x >=1, x <  1, x <=1, x == 1, x != 1, !(x == 1))
+ne <- expression(x <= 1, x < 1, x >= 1, x > 1, x != 1, x == 1, (x == 1))
+expect_identical( as.expression(lapply(e, validate:::negate))
+                , ne
+                )
+
+## injecting eps
+e <- quote(x >= 1)
+expect_identical( validate:::replace_lin(e, dat=data.frame(x=1), eps_ineq = 0.1)
+                , quote(x - 1 >= -0.1)
+                )
+
+e <- quote(!x>0)
+expect_identical( validate:::replace_lin(e, dat=data.frame(x=1), eps_ineq = 0.1)
+                , quote(x <= 0
+                )
+)
+
+e <- quote(!(x>0))
+expect_identical( validate:::replace_lin(e, dat=data.frame(x=1), eps_ineq = 0.1)
+                  , quote(x <= 0
+                  )
+)
+
+
+e <- quote(if (x > 1) y == 1 else z > 1)
+expect_identical( validate:::replace_lin(e, dat=data.frame(x=1, y=1,z=1),eps_ineq = 0.1, eps_eq = 0.2)
+                , quote(if (x > 1) abs(y - 1) <= 0.2 else z > 1)
+)
+
+e <- quote(if (x > 1) y == 1 else z > 1)
+e <- validate:::replace_if(e)
+e <- validate:::replace_lin(e, dat=data.frame(x=1,y=1,z=1))
+expect_identical( e 
+                , quote(  (x <= 1  | (abs(y - 1) <= 0.1)) 
+                       & ((x >  1) | (z > 1))
+                       )
+                )
+
+e <- quote(a == b)
+e <- validate:::replace_lin(e, dat=data.frame(a = 1, b=2))
+expect_identical( e, quote(abs(a - b) <= 0.1))
+
+e <- quote(a == b)
+e <- validate:::replace_lin(e, dat=data.frame(a = "A", b="B"))
+expect_identical( e, quote(a == b))
+
+                  
\ No newline at end of file
